==> apache-camel-3.21.5-src.zip: apache-camel-3.21.5/components/camel-braintree/src/test/java/org/apache/camel/component/braintree/AddOnGatewayIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.braintree;

import java.util.List;

import com.braintreegateway.AddOn;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.braintree.internal.AddOnGatewayApiMethod;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledIfSystemProperty;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.jupiter.api.Assertions.assertNotNull;

@EnabledIfSystemProperty(named = "braintreeAuthenticationType", matches = ".*")
public class AddOnGatewayIT extends AbstractBraintreeTestSupport {

    private static final Logger LOG = LoggerFactory.getLogger(AddOnGatewayIT.class);
    private static final String PATH_PREFIX = getApiNameAsString(AddOnGatewayApiMethod.class);

    @Disabled
    @Test
    public void testAll() {
        final List<AddOn> result = requestBody("direct://ALL", null, List.class);

        assertNotNull(result, "all result");
        LOG.debug("all: " + result);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // test route for all
                from("direct://ALL")
                        .to("braintree://" + PATH_PREFIX + "/all");
            }
        };
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-braintree/src/test/java/org/apache/camel/component/braintree/AddOnGatewayIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.braintree;

import java.util.List;

import com.braintreegateway.AddOn;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.braintree.internal.AddOnGatewayApiMethod;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.EnabledIfSystemProperty;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.jupiter.api.Assertions.assertNotNull;

@EnabledIfSystemProperty(named = "braintreeAuthenticationType", matches = ".*")
public class AddOnGatewayIT extends AbstractBraintreeTestSupport {

    private static final Logger LOG = LoggerFactory.getLogger(AddOnGatewayIT.class);
    private static final String PATH_PREFIX = getApiNameAsString(AddOnGatewayApiMethod.class);

    @Disabled
    @Test
    public void testAll() {
        final List<AddOn> result = requestBody("direct://ALL", null, List.class);

        assertNotNull(result, "all result");
        LOG.debug("all: {}", result);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                // test route for all
                from("direct://ALL")
                        .to("braintree://" + PATH_PREFIX + "/all");
            }
        };
    }
}
